==> layer-0.10.2360362101.tar.gz: layer-0.10.2360362101/README.md <==
<!---
Copyright 2022 Layer. All rights reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
-->

<p align="center">
    <br>
    <a href="https://layer.ai">
        <img src="https://app.layer.ai/assets/logo.svg" width="200" alt="Layer"/>
    </a>
    <br>
<p>
<p align="center">
    <a href="https://github.com/layerai/sdk/blob/main/LICENSE">
        <img alt="License" src="https://img.shields.io/github/license/layer/sdk.svg?color=blue">
    </a>
    <a href="https://docs.app.layer.ai">
        <img alt="Documentation" src="https://img.shields.io/badge/docs-online-success">
    </a>
    <a href="https://github.com/layerai/sdk/actions/workflows/check.yml">
        <img alt="Build" src="https://img.shields.io/github/workflow/status/layerai/sdk/check/main">
    </a>
    <a href="https://pypi.python.org/pypi/layer">
        <img alt="PyPI" src="https://img.shields.io/pypi/v/layer.svg">
    </a>
    <a href="https://github.com/layer/sdk/blob/main/CODE_OF_CONDUCT.md">
        <img alt="Contributor Covenant" src="https://img.shields.io/badge/contributor%20covenant-v2.1%20adopted-blueviolet.svg">
    </a>
</p>

# Layer

Layer helps you create production-grade ML pipelines with a seamless local↔cloud transition while enabling collaboration with semantic versioning, extensive artifact logging and dynamic reporting.

[Start for Free!](https://app.layer.ai)

## Getting Started

The simplest way to get started with Layer is to go through the [quickstart guide](https://docs.app.layer.ai/docs/getting-started).

==> layer-0.10.2381164543.tar.gz: layer-0.10.2381164543/README.md <==
<!---
Copyright 2022 Layer. All rights reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
-->

<p align="center">
    <br>
    <a href="https://layer.ai">
        <img src="https://app.layer.ai/assets/logo.svg" width="200" alt="Layer"/>
    </a>
    <br>
<p>
<p align="center">
    <a href="https://github.com/layerai/sdk/blob/main/LICENSE">
        <img alt="License" src="https://img.shields.io/github/license/layerai/sdk.svg?color=blue">
    </a>
    <a href="https://docs.app.layer.ai">
        <img alt="Documentation" src="https://img.shields.io/badge/docs-online-success">
    </a>
    <a href="https://github.com/layerai/sdk/actions/workflows/check.yml">
        <img alt="Build" src="https://img.shields.io/github/workflow/status/layerai/sdk/Check">
    </a>
    <a href="https://pypi.python.org/pypi/layer">
        <img alt="PyPI" src="https://img.shields.io/pypi/v/layer.svg">
    </a>
    <a href="https://github.com/layer/sdk/blob/main/CODE_OF_CONDUCT.md">
        <img alt="Contributor Covenant" src="https://img.shields.io/badge/contributor%20covenant-v2.1%20adopted-blueviolet.svg">
    </a>
</p>

# Layer

Layer helps you create production-grade ML pipelines with a seamless local↔cloud transition while enabling collaboration with semantic versioning, extensive artifact logging and dynamic reporting.

[Start for Free!](https://app.layer.ai)

## Getting Started

The simplest way to get started with Layer is to go through the [quickstart guide](https://docs.app.layer.ai/docs/getting-started).
